==> VirtualBoxSDK-4.2.18-88780.zip: org/virtualbox_4_2/jaxws/IFileSeek.java <==

package org.virtualbox_4_2.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="offset" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="whence" type="{http://www.virtualbox.org/}FileSeekType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "offset",
    "whence"
})
@XmlRootElement(name = "IFile_seek")
public class IFileSeek {

    @XmlElement(required = true)
    protected String _this;
    protected long offset;
    @XmlElement(required = true)
    protected FileSeekType whence;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     */
    public long getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     */
    public void setOffset(long value) {
        this.offset = value;
    }

    /**
     * Gets the value of the whence property.
     * 
     * @return
     *     possible object is
     *     {@link FileSeekType }
     *     
     */
    public FileSeekType getWhence() {
        return whence;
    }

    /**
     * Sets the value of the whence property.
     * 
     * @param value
     *     allowed object is
     *     {@link FileSeekType }
     *     
     */
    public void setWhence(FileSeekType value) {
        this.whence = value;
    }

}

==> VirtualBoxSDK-5.0.0-101573.zip: org/virtualbox_5_0/jaxws/IFileSeek.java <==

package org.virtualbox_5_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="offset" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="whence" type="{http://www.virtualbox.org/}FileSeekOrigin"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "offset",
    "whence"
})
@XmlRootElement(name = "IFile_seek")
public class IFileSeek {

    @XmlElement(required = true)
    protected String _this;
    protected long offset;
    @XmlElement(required = true)
    protected FileSeekOrigin whence;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     */
    public long getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     */
    public void setOffset(long value) {
        this.offset = value;
    }

    /**
     * Gets the value of the whence property.
     * 
     * @return
     *     possible object is
     *     {@link FileSeekOrigin }
     *     
     */
    public FileSeekOrigin getWhence() {
        return whence;
    }

    /**
     * Sets the value of the whence property.
     * 
     * @param value
     *     allowed object is
     *     {@link FileSeekOrigin }
     *     
     */
    public void setWhence(FileSeekOrigin value) {
        this.whence = value;
    }

}
